dwww Home | Manual pages | Find package

xfs_ncheck(8)               System Manager's Manual               xfs_ncheck(8)

NAME
       xfs_ncheck - generate pathnames from i-numbers for XFS

SYNOPSIS
       xfs_ncheck [ -i ino ] ... [ -f ] [ -s ] [ -l logdev ] device
       xfs_ncheck -V

DESCRIPTION
       xfs_ncheck  with  no -i arguments generates an inode number and pathname
       list of all files on the given filesystem. Names of directory files  are
       followed  by /..  The output is not sorted in any particular order.  The
       filesystem to be examined is specified by  the  device  argument,  which
       should  be  the  disk  or volume device for the filesystem.  Filesystems
       stored in files can also be checked, using the -f flag.

OPTIONS
       -f       Specifies that the filesystem image to be processed  is  stored
                in  a regular file at device (see the mkfs.xfs -d file option).
                This might happen if an image copy of  a  filesystem  has  been
                made into an ordinary file.

       -l logdev
                Specifies  the  device  where the filesystem's external log re-
                sides.  Only for those filesystems which use an  external  log.
                See  the mkfs.xfs -l option, and refer to xfs(5) for a detailed
                description of the XFS log.

       -s       Limits the report to special files  and  files  with  setuserid
                mode.  This option may be used to detect violations of security
                policy.

       -i ino   Limits  the report to only those files whose inode numbers fol-
                low.  May be given multiple times to select multiple inode num-
                bers.

       -V       Prints the version number and exits.

       If the filesystem is seriously corrupted, or very busy and looks like it
       is corrupt, a message of  the  form  that  would  be  generated  by  the
       xfs_db(8) "check" command may appear.

       xfs_ncheck is only useful with XFS filesystems.

SEE ALSO
       mkfs.xfs(8), xfs(5).

                                                                  xfs_ncheck(8)

Generated by dwww version 1.16 on Sat Oct 3 06:23:42 CEST 2026.